@@ -57,6 +57,9 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 	private CqlFilterPanel cqlFilterPanel = new CqlFilterPanel(this);
 
 	private ClickDataInfo lastClickDataInfo = null;
+	
+	//ADDED BY FRANCESCO
+	public enum LayerType {RASTER, FEATURETYPE};
 
 
 	/**
@@ -790,5 +793,111 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			showDataPanel();
 		}
 	}
+	
+	/**
+	 * 
+	 * Addeb by Francesco
+	 * Extension of addLayerByWms, with input parameter is external layer
+	 * @param title
+	 * @param layerName
+	 * @param url
+	 * @param isExternal
+	 * @param isBase
+	 * @param displayInLayerSwitcher
+	 * @param styles - the first style of list must be the default style
+	 * @param onTop
+	 */
+	public void addLayerByWms(LayerType layerType, String title, String layerName, String url, boolean isExternal, boolean isBase, boolean displayInLayerSwitcher, ArrayList<String> styles, boolean onTop) {
+		LayerItem l = new LayerItem();
+		l.setBaseLayer(isBase);
+		l.setTitle(title);
+		l.setName(layerName);
+		l.setLayer(layerName);
+		l.setUrl(url);		
+		l.setGeoserverUrl(url);
+		l.setGeoserverWmsUrl(url);
+		l.setExternal(isExternal);
+		l.setOpacity(1d);
+		l.setBuffer(2);
+
+		switch (layerType) {
+		
+		//TODO IMPLEMENT THIS CASE
+			case RASTER:
+				
+				l.setHasLegend(false);
+				l.setBaseLayer(true);
+				l.setTrasparent(false);
+				l.setClickData(false);
+				
+				break;
+				
+			case FEATURETYPE:
+				
+				//CASE FEATURE TYPE
+				l.setBaseLayer(false);
+				l.setClickData(true);
+				l.setTrasparent(true);
+				
+				break;
+			
+		}
+
+		if(styles!=null & styles.size()>0){
+			l.setHasLegend(true);
+			l.setDefaultStyle(styles.get(0));
+			l.setStyle(styles.get(0));
+			l.setStyles(styles);
+		}
+
+		List<LayerItem> layerItems = new ArrayList<LayerItem>();
+		layerItems.add(l);
+		
+		openLayersMap.addLayerItemByWms(l, displayInLayerSwitcher);
+		layersPanel.addLayerItems(layerItems, onTop);
+		layersPanel.updateLayersOrder();
+	}
+	
+
+	/**
+	 * Addeb by Francesco
+	 * 
+	 * @param layerType
+	 * @param listLayerItem
+	 * @param onTop
+	 */
+	public void addLayerItemsByWms(LayerType layerType, List<LayerItem> listLayerItem, boolean onTop) {
+
+		for (LayerItem l : listLayerItem) {
+
+			switch (layerType) {
+			
+			//TODO IMPLEMENT THIS CASE
+				case RASTER:
+					
+					l.setHasLegend(false);
+					l.setBaseLayer(true);
+					l.setTrasparent(false);
+					l.setClickData(false);
+					
+					break;
+					
+				case FEATURETYPE:
+					
+					//CASE FEATURE TYPE
+					l.setBaseLayer(false);
+					l.setClickData(true);
+					l.setTrasparent(true);
+					
+					break;
+				
+			}
+				
+			openLayersMap.addLayerItemByWms(l, false);
+		}
+
+		layersPanel.addLayerItems(listLayerItem, onTop);
+		layersPanel.updateLayersOrder();
+	}
 
 }
